@@ -142,7 +142,14 @@ class LongHandlerEN(Operation):
 
         # self.weights = {k: i for k, i in sorted(self.weights.items(), key=lambda x: x[1])}
 
+    def init_var(self):
+        self.quota_left = 0
+        self.quota_en = 0
+        self.bracket_left = 0
+        self.bracket_right = 0
+
     def operate(self, state: EnSequence) -> EnSequence:
+        self.init_var()
         temps_state = copy.copy(state)
         self.get_init_quota_bracket(state)
         cut_id, dialog_success = self.dialog_handler(temps_state)
